@@ -3,7 +3,7 @@
 /*               This file is part of the program and library                */
 /*    PaPILO --- Parallel Presolve for Integer and Linear Optimization       */
 /*                                                                           */
-/* Copyright (C) 2020-2024 Zuse Institute Berlin (ZIB)                       */
+/* Copyright (C) 2020-2025 Zuse Institute Berlin (ZIB)                       */
 /*                                                                           */
 /* This program is free software: you can redistribute it and/or modify      */
 /* it under the terms of the GNU Lesser General Public License as published  */
@@ -25,16 +25,14 @@
 
 #define UNUSED(expr) do { (void)(expr); } while (0)
 
-#include "papilo/misc/Vec.hpp"
-#include <cassert>
-#include <stdexcept>
-
 #include "papilo/core/Problem.hpp"
 #include "papilo/interfaces/SolverInterface.hpp"
+#include "papilo/misc/Vec.hpp"
 #include "scip/cons_linear.h"
 #include "scip/scip.h"
-
 #include "scip/struct_paramset.h"
+#include <cassert>
+#include <stdexcept>
 
 namespace papilo
 {
@@ -69,35 +67,32 @@ class ScipInterface : public SolverInterface<REAL>
 
       for( int i = 0; i < ncols; ++i )
       {
+         assert(!domains.flags[i].test( ColFlag::kInactive ));
          SCIP_VAR* var;
-         assert( !domains.flags[i].test( ColFlag::kInactive ) );
-
          SCIP_Real lb = domains.flags[i].test( ColFlag::kLbInf )
-                            ? -SCIPinfinity( scip )
-                            : SCIP_Real( domains.lower_bounds[i] );
+                            ? -SCIPinfinity(scip)
+                            : SCIP_Real(domains.lower_bounds[i]);
          SCIP_Real ub = domains.flags[i].test( ColFlag::kUbInf )
-                            ? SCIPinfinity( scip )
-                            : SCIP_Real( domains.upper_bounds[i] );
-         SCIP_VARTYPE type;
+                            ? SCIPinfinity(scip)
+                            : SCIP_Real(domains.upper_bounds[i]);
+         assert(lb < ub);
+         SCIP_VARTYPE vartype;
          if( domains.flags[i].test( ColFlag::kIntegral ) )
          {
-            if( lb == REAL{ 0 } && ub == REAL{ 1 } )
-               type = SCIP_VARTYPE_BINARY;
+            if( lb >= 0 && ub <= 1 )
+               vartype = SCIP_VARTYPE_BINARY;
             else
-               type = SCIP_VARTYPE_INTEGER;
+               vartype = SCIP_VARTYPE_INTEGER;
          }
          else if( domains.flags[i].test( ColFlag::kImplInt ) )
-            type = SCIP_VARTYPE_IMPLINT;
+            vartype = SCIP_VARTYPE_IMPLINT;
          else
-            type = SCIP_VARTYPE_CONTINUOUS;
-
-         SCIP_CALL( SCIPcreateVarBasic(
-             scip, &var, varNames[origColMap[i]].c_str(), lb, ub,
-             SCIP_Real( obj.coefficients[i] ), type ) );
-         SCIP_CALL( SCIPaddVar( scip, var ) );
+            vartype = SCIP_VARTYPE_CONTINUOUS;
+         SCIP_CALL( SCIPcreateVarBasic(scip, &var, varNames[origColMap[i]].c_str(), lb, ub,
+               SCIP_Real(obj.coefficients[i]), vartype) );
          vars[i] = var;
-
-         SCIP_CALL( SCIPreleaseVar( scip, &var ) );
+         SCIP_CALL( SCIPaddVar(scip, var) );
+         SCIP_CALL( SCIPreleaseVar(scip, &var) );
       }
 
       Vec<SCIP_VAR*> consvars;
@@ -198,33 +193,32 @@ class ScipInterface : public SolverInterface<REAL>
       for( int i = 0; i < ncols; ++i )
       {
          int col = colset[i];
+         assert(!domains.flags[col].test( ColFlag::kInactive ));
          SCIP_VAR* var;
-         assert( !domains.flags[col].test( ColFlag::kInactive ) );
-
          SCIP_Real lb = domains.flags[col].test( ColFlag::kLbInf )
-                            ? -SCIPinfinity( scip )
-                            : SCIP_Real( domains.lower_bounds[col] );
+                            ? -SCIPinfinity(scip)
+                            : SCIP_Real(domains.lower_bounds[col]);
          SCIP_Real ub = domains.flags[col].test( ColFlag::kUbInf )
-                            ? SCIPinfinity( scip )
-                            : SCIP_Real( domains.upper_bounds[col] );
-         SCIP_VARTYPE type;
+                            ? SCIPinfinity(scip)
+                            : SCIP_Real(domains.upper_bounds[col]);
+         assert(lb < ub);
+         SCIP_VARTYPE vartype;
          if( domains.flags[col].test( ColFlag::kIntegral ) )
          {
-            if( lb == REAL{ 0 } && ub == REAL{ 1 } )
-               type = SCIP_VARTYPE_BINARY;
+            if( lb >= 0 && ub <= 1 )
+               vartype = SCIP_VARTYPE_BINARY;
             else
-               type = SCIP_VARTYPE_INTEGER;
+               vartype = SCIP_VARTYPE_INTEGER;
          }
+         else if( domains.flags[col].test( ColFlag::kImplInt ) )
+            vartype = SCIP_VARTYPE_IMPLINT;
          else
-            type = SCIP_VARTYPE_CONTINUOUS;
-
-         SCIP_CALL( SCIPcreateVarBasic(
-             scip, &var, varNames[origColMap[col]].c_str(), lb, ub,
-             SCIP_Real( obj.coefficients[col] ), type ) );
-         SCIP_CALL( SCIPaddVar( scip, var ) );
+            vartype = SCIP_VARTYPE_CONTINUOUS;
+         SCIP_CALL( SCIPcreateVarBasic(scip, &var, varNames[origColMap[col]].c_str(), lb, ub,
+               SCIP_Real(obj.coefficients[col]), vartype) );
          vars[i] = var;
-
-         SCIP_CALL( SCIPreleaseVar( scip, &var ) );
+         SCIP_CALL( SCIPaddVar(scip, var) );
+         SCIP_CALL( SCIPreleaseVar(scip, &var) );
       }
 
       Vec<SCIP_VAR*> consvars;
@@ -389,8 +383,12 @@ class ScipInterface : public SolverInterface<REAL>
       case SCIP_STATUS_SOLLIMIT:
       case SCIP_STATUS_BESTSOLLIMIT:
       case SCIP_STATUS_RESTARTLIMIT:
-#if SCIP_VERSION_MAJOR >= 6
+#if SCIP_VERSION_API >= 22
       case SCIP_STATUS_TERMINATE:
+#endif
+#if SCIP_VERSION_API >= 115
+      case SCIP_STATUS_PRIMALLIMIT:
+      case SCIP_STATUS_DUALLIMIT:
 #endif
          this->status = SolverStatus::kInterrupted;
          break;
